==> nextbus-graphql-0.0.3.tgz: package/lib/scripts/updateSchema.js <==
'use strict';

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _graphql = require('graphql');

var _utilities = require('graphql/utilities');

var _schema = require('../schema');

var _schema2 = _interopRequireDefault(_schema);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { return step("next", value); }, function (err) { return step("throw", err); }); } } return step("next"); }); }; }

// Create lib/ if it doesn't exist
const libDir = _path2.default.resolve(__dirname, '../../lib');
try {
  _fs2.default.statSync(libDir);
} catch (e) {
  _fs2.default.mkdirSync(libDir);
}

// Save JSON of full schema introspection for Babel Relay Plugin to use
_asyncToGenerator(function* () {
  const result = yield (0, _graphql.graphql)(_schema2.default, _utilities.introspectionQuery);
  if (result.errors) {
    console.error('ERROR introspecting schema: ', JSON.stringify(result.errors, null, 2));
  } else {
    _fs2.default.writeFileSync(_path2.default.join(libDir, 'schema.json'), JSON.stringify(result, null, 2));
  }
})();

// Save user readable type system shorthand of schema
_fs2.default.writeFileSync(_path2.default.join(libDir, 'schema.graphql'), (0, _utilities.printSchema)(_schema2.default));

==> nextbus-graphql-0.0.4.tgz: package/lib/scripts/updateSchema.js <==
'use strict';

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _graphql = require('graphql');

var _utilities = require('graphql/utilities');

var _schema = require('../schema');

var _schema2 = _interopRequireDefault(_schema);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

// Create lib/ if it doesn't exist
const libDir = _path2.default.resolve(__dirname, '../../lib');
try {
  _fs2.default.statSync(libDir);
} catch (e) {
  _fs2.default.mkdirSync(libDir);
}

// Save JSON of full schema introspection for Babel Relay Plugin to use
_asyncToGenerator(function* () {
  const result = yield (0, _graphql.graphql)(_schema2.default, _utilities.introspectionQuery);
  if (result.errors) {
    console.error('ERROR introspecting schema: ', JSON.stringify(result.errors, null, 2));
  } else {
    _fs2.default.writeFileSync(_path2.default.join(libDir, 'schema.json'), JSON.stringify(result, null, 2));
  }
})();

// Save user readable type system shorthand of schema
_fs2.default.writeFileSync(_path2.default.join(libDir, 'schema.graphql'), (0, _utilities.printSchema)(_schema2.default));
